pub struct Tape {
pub actions: Vec<Box<dyn TapeAction>>,
}Expand description
The linear log of operations required to compute gradients.
Fields
actions: Vec<Box<dyn TapeAction>>Implementations
Sourceimpl Tape
impl Tape
pub fn new() -> Self
Sourcepub fn push(&mut self, action: Box<dyn TapeAction>)
pub fn push(&mut self, action: Box<dyn TapeAction>)
Appends a new operation to the history log.
Sourcepub fn take_all(&mut self) -> Vec<Box<dyn TapeAction>>
pub fn take_all(&mut self) -> Vec<Box<dyn TapeAction>>
Extracts the entire history log, leaving the Tape completely empty. This is called right before executing the backward pass.